import{P as r}from"./Passwordless.b90967a1.js";import{d as a,ex as i,b as d,c,e as s,eq as _,t as m}from"./registerWidgets.daf4e0d4.js";import{M as p}from"./member.5c2dc66c.js";import{W as f}from"./WidgetsFrame.88a82b36.js";import"./CircularLoading.56bf1e90.js";import"./lottie.1c3e1229.js";import"./icons.74a49ba5.js";import"./passwordlessManager.cc6b1127.js";import"./pubsub.bf966380.js";import"./storage.62ab7605.js";import"./gateway.c1bf584f.js";import"./activeRecord.8789da8d.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="1308c87a-7e31-4eec-89f8-b8ed0197d744",e._sentryDebugIdIdentifier="sentry-dbid-1308c87a-7e31-4eec-89f8-b8ed0197d744")}catch{}})();const l={class:"login"},u=a({__name:"Login",setup(e){const o=i();async function t(n){await p.login(),o.push({name:"home"})}return(n,g)=>(d(),c("div",l,[s(f,{theme:"white","main-color":"#d14056","font-family":"sans-serif",runtime:"dash"},{default:_(()=>[s(r,{class:"passwordless",onDone:t})]),_:1})]))}});const C=m(u,[["__scopeId","data-v-0e3dc783"]]);export{C as default};
//# sourceMappingURL=Login.f67614ba.js.map
