import{d as p,ey as u,F as f,b as y,u as g,bu as _}from"./registerWidgets.daf4e0d4.js";import{a as w}from"./asyncComputed.ea0509ca.js";import"./gateway.c1bf584f.js";import{M as s}from"./member.5c2dc66c.js";import"./index.1451144e.js";import{C as I}from"./CrudView.6743e372.js";import"./passwordlessManager.cc6b1127.js";import"./pubsub.bf966380.js";import"./storage.62ab7605.js";import"./activeRecord.8789da8d.js";import"./DropdownMenu.e36b430d.js";import"./Modal.041843ec.js";import"./LoadingIndicator.465c522f.js";import"./lottie.1c3e1229.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="d42d05b0-ee4f-42db-9731-e5f3f1bdbe8d",e._sentryDebugIdIdentifier="sentry-dbid-d42d05b0-ee4f-42db-9731-e5f3f1bdbe8d")}catch{}})();const N=p({__name:"Members",setup(e){const r=u().params.organizationId,i=[{key:"email",label:"Email"}],m=async t=>{await s.create(r,t.email),c()},{loading:d,result:l,refetch:c}=w(()=>s.list(r)),b=f(()=>{var t,a;return{columns:[{name:"Email"},{name:"Role"}],rows:(a=(t=l.value)==null?void 0:t.map(n=>({key:n.email,cells:[{text:n.email,classes:["title","centered"]},{text:n.role,classes:["centered"]}]})))!=null?a:[]}});return(t,a)=>(y(),g(I,{"entity-name":"members",loading:_(d),title:"Organization members",description:"List all organization members.","empty-title":"No members yet",table:b.value,"create-button-text":"Add members",fields:i,onCreate:m},null,8,["loading","table"]))}});export{N as default};
//# sourceMappingURL=Members.36b848c3.js.map
